@@ -1,7 +1,5 @@
-#' @keywords internal
-"_PACKAGE"
-
-#' @importFrom Rcpp sourceCpp
+#' @importFrom Rcpp evalCpp
 #' @importFrom RcppParallel RcppParallelLibs
 #' @useDynLib qualpalr, .registration = TRUE
-NULL
+#' @keywords internal
+"_PACKAGE"
\ No newline at end of file
